@@ -1,7 +1,7 @@
-id = "54990ee22a0e95937ec218f008f20ba3b9fdbda8"
-date = "2015-06-01 17:09:52 +0000"
+id = "359a04aa520841cc8a4d9ef28fedb8642d58abd0"
+date = "2015-07-23 23:40:23 +0000"
 branch = "master"
-tag = "pylal-0.7.2-v1"
+tag = "pylal-v0.8.0-v1"
 if tag == "None":
     tag = None
 author = "Kipp Cannon <kipp.cannon@ligo.org>"
@@ -10,11 +10,11 @@ committer = "Kipp Cannon <kipp.cannon@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: master
-Tag: pylal-0.7.2-v1
-Id: 54990ee22a0e95937ec218f008f20ba3b9fdbda8
+Tag: pylal-v0.8.0-v1
+Id: 359a04aa520841cc8a4d9ef28fedb8642d58abd0
 
 Builder: Kipp Cannon <kipp.cannon@ligo.org>
-Build date: 2015-06-01 17:10:24 +0000
+Build date: 2015-07-23 23:41:54 +0000
 Repository status: CLEAN: All modifications committed"""
 
 import warnings
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError, onmismatch + " is an unrecognized value of onmismatch"
-    if foreign_id == "54990ee22a0e95937ec218f008f20ba3b9fdbda8":
+    if foreign_id == "359a04aa520841cc8a4d9ef28fedb8642d58abd0":
         return
-    msg = "Program id (54990ee22a0e95937ec218f008f20ba3b9fdbda8) does not match given id (%s)." % foreign_id
+    msg = "Program id (359a04aa520841cc8a4d9ef28fedb8642d58abd0) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError, msg
 
