@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2013  Kipp Cannon
+# Copyright (C) 2007-2014  Kipp Cannon
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -34,7 +34,7 @@ import sys
 from glue import iterutils
 from glue.ligolw import ligolw
 from glue.ligolw import lsctables
-from glue.ligolw import utils
+from glue.ligolw import utils as ligolw_utils
 from glue.ligolw.utils import process as ligolw_process
 from glue.ligolw.utils import search_summary as ligolw_search_summary
 from glue.offsetvector import offsetvector
@@ -84,38 +84,87 @@ class BurcaCoincParamsDistributions(snglcoinc.CoincParamsDistributions):
 		"H1_H2_dband": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_L1_dband": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H2_L1_dband": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"H1_V1_dband": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"L1_V1_dband": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_H2_ddur": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_L1_ddur": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H2_L1_ddur": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"H1_V1_ddur": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"L1_V1_ddur": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_H2_df": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_L1_df": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H2_L1_df": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"H1_V1_df": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"L1_V1_df": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_H2_dh": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_L1_dh": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H2_L1_dh": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"H1_V1_dh": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
+		"L1_V1_dh": rate.NDBins((rate.LinearBins(-2.0, +2.0, 12001), rate.LinearBins(0.0, 2 * math.pi, 61))),
 		"H1_H2_dt": dt_binning("H1", "H2"),
 		"H1_L1_dt": dt_binning("H1", "L1"),
-		"H2_L1_dt": dt_binning("H2", "L1")
+		"H2_L1_dt": dt_binning("H2", "L1"),
+		"H1_V1_dt": dt_binning("H1", "V1"),
+		"L1_V1_dt": dt_binning("L1", "V1")
 	}
 
 	filters = {
 		"H1_H2_dband": rate.gaussian_window(11, 5),
 		"H1_L1_dband": rate.gaussian_window(11, 5),
 		"H2_L1_dband": rate.gaussian_window(11, 5),
+		"H1_V1_dband": rate.gaussian_window(11, 5),
+		"L1_V1_dband": rate.gaussian_window(11, 5),
 		"H1_H2_ddur": rate.gaussian_window(11, 5),
 		"H1_L1_ddur": rate.gaussian_window(11, 5),
 		"H2_L1_ddur": rate.gaussian_window(11, 5),
+		"H1_V1_ddur": rate.gaussian_window(11, 5),
+		"L1_V1_ddur": rate.gaussian_window(11, 5),
 		"H1_H2_df": rate.gaussian_window(11, 5),
 		"H1_L1_df": rate.gaussian_window(11, 5),
 		"H2_L1_df": rate.gaussian_window(11, 5),
+		"H1_V1_df": rate.gaussian_window(11, 5),
+		"L1_V1_df": rate.gaussian_window(11, 5),
 		"H1_H2_dh": rate.gaussian_window(11, 5),
+		"H1_V1_df": rate.gaussian_window(11, 5),
+		"L1_V1_df": rate.gaussian_window(11, 5),
 		"H1_L1_dh": rate.gaussian_window(11, 5),
 		"H2_L1_dh": rate.gaussian_window(11, 5),
 		"H1_H2_dt": rate.gaussian_window(11, 5),
 		"H1_L1_dt": rate.gaussian_window(11, 5),
-		"H2_L1_dt": rate.gaussian_window(11, 5)
+		"H2_L1_dt": rate.gaussian_window(11, 5),
+		"H1_V1_dh": rate.gaussian_window(11, 5),
+		"L2_V1_dh": rate.gaussian_window(11, 5)
 	}
 
+	@classmethod
+	def from_filenames(cls, filenames, name, verbose = False):
+		"""
+		Convenience function to deserialize
+		CoincParamsDistributions objects from a collection of XML
+		files and return their sum.  The return value is a
+		two-element tuple.  The first element is the deserialized
+		and summed CoincParamsDistributions object, the second is a
+		segmentlistdict indicating the interval of time spanned by
+		the out segments in the search_summary rows matching the
+		process IDs that were attached to the
+		CoincParamsDistributions objects in the XML.
+		"""
+		self = None
+		for n, filename in enumerate(filenames, 1):
+			if verbose:
+				print >>sys.stderr, "%d/%d:" % (n, len(filenames)),
+			xmldoc = ligolw_utils.load_filename(filename, verbose = verbose, contenthandler = cls.contenthandler)
+			if self is None:
+				self = cls.from_xml(xmldoc, name)
+				seglists = lsctables.SearchSummaryTable.get_table(xmldoc).get_out_segmentlistdict(set([self.process_id])).coalesce()
+			else:
+				other = cls.from_xml(xmldoc, name)
+				self += other
+				seglists |= lsctables.SearchSummaryTable.get_table(xmldoc).get_out_segmentlistdict(set([other.process_id])).coalesce()
+				del other
+			xmldoc.unlink()
+		return self, seglists
+
 
 #
 # All sky version
@@ -143,8 +192,9 @@ class EPAllSkyCoincParamsDistributions(BurcaCoincParamsDistributions):
 		# FIXME: this time is available as the peak_time in the
 		# multi_burst table, and it should be retrieved from that
 		# table instead of being recomputed
-		t = events[0].get_peak()
-		t += sum(float(event.get_peak() - t) * event.ms_snr**2.0 for event in events) / sum(event.ms_snr**2.0 for event in events)
+		events = tuple(events)
+		t = events[0].peak
+		t += sum(float(event.peak - t) * event.ms_snr**2.0 for event in events) / sum(event.ms_snr**2.0 for event in events)
 		gmst = date.XLALGreenwichMeanSiderealTime(t) % (2 * math.pi)
 
 		for event1, event2 in iterutils.choices(sorted(events, lambda a, b: cmp(a.ifo, b.ifo)), 2):
@@ -159,7 +209,7 @@ class EPAllSkyCoincParamsDistributions(BurcaCoincParamsDistributions):
 			# more than one event from a given instrument, the smallest
 			# deltas are recorded
 
-			dt = float(event1.get_peak() + offsetvector[event1.ifo] - event2.get_peak() - offsetvector[event2.ifo])
+			dt = float(event1.peak + offsetvector[event1.ifo] - event2.peak - offsetvector[event2.ifo])
 			name = "%sdt" % prefix
 			if name not in params or abs(params[name][0]) > abs(dt):
 				#params[name] = (dt,)
@@ -204,11 +254,10 @@ def delay_and_amplitude_correct(event, ra, dec):
 
 	# delay-correct the event to the geocentre
 
-	peak = event.get_peak()
-	delay = date.XLALTimeDelayFromEarthCenter(detector.location, ra, dec, peak)
-	event.set_peak(peak - delay)
-	event.set_start(event.get_start() - delay)
-	event.set_ms_start(event.get_ms_start() - delay)
+	delay = date.XLALTimeDelayFromEarthCenter(detector.location, ra, dec, event.peak)
+	event.peak -= delay
+	event.start -= delay
+	event.ms_start -= delay
 
 	# amplitude-correct the event using the polarization-averaged
 	# antenna response
